import { 
    TableHead,
    TableRow,
    TableCell,
    Checkbox,
    TableSortLabel,
    Box,
} from '@mui/material'

import { visuallyHidden } from '@mui/utils';

export const rows = [
    createData('Cupcake', 305, 3.7, 67, 4.3, 'Nice', 'Good'),
    createData('Cupcake 1', 305, 3.7, 67, 4.3, 'Nice', 'Good'),
    createData('Cupcake 2', 305, 3.7, 67, 4.3, 'Nice', 'Good'),
    createData('Cupcake 3', 305, 3.7, 67, 4.3, 'Nice', 'Good'),
    createData('Cupcake 4', 305, 3.7, 67, 4.3, 'Nice', 'Good'),
]

export function createData(name, calories, fat, carbs, protein) {
    return {
        name,
        calories,
        fat,
        carbs,
        protein,
    };
}

function descendingComparator(a, b, orderBy) {
    if (b[orderBy] < a[orderBy]) {
        return -1;
    }
    if (b[orderBy] > a[orderBy]) {
        return 1;
    }
    return 0;
}

export function Comparar(order, orderBy) {
    return order === 'desc'
        ? (a, b) => descendingComparator(a, b, orderBy)
        : (a, b) => -descendingComparator(a, b, orderBy);
}

export function Cuerpo(array, comparator) {
    const stabilizedThis = array.map((el, index) => [el, index]);
    stabilizedThis.sort((a, b) => {
        const order = comparator(a[0], b[0]);
        if (order !== 0) {
            return order;
        }
        return a[1] - b[1];
    });
    return stabilizedThis.map((el) => el[0]);
}

export const encabezados = [
    {
        id: 'pass',
        numeric: false,
        disablePadding: true,
        label: 'Contraseñas',
    },
    {
        id: 'nivel',
        numeric: true,
        disablePadding: false,
        label: 'Nivel',
    },
    {
        id: 'puesto',
        numeric: true,
        disablePadding: false,
        label: 'Puesto',
    },
    {
        id: 'cui',
        numeric: true,
        disablePadding: false,
        label: 'CUI/Cedula',
    },
    {
        id: 'uso',
        numeric: true,
        disablePadding: false,
        label: 'En uso?',
    },
    {
        id: 'picture',
        numeric: true,
        disablePadding: false,
        label: 'Fotografía',
    },
    {
        id: 'cv',
        numeric: true,
        disablePadding: false,
        label: 'Con CV',
    },
    {
        id: 'replic',
        numeric: true,
        disablePadding: false,
        label: 'Replicar',
    },
    {
        id: 'ope',
        numeric: true,
        disablePadding: false,
        label: 'Operacion',
    },
]

export function TableHeader(props){

    const { onSelectAllClick, order, orderBy, numSelected, rowCount, onRequestSort } =
        props;
    const createSortHandler = (property) => (event) => {
        onRequestSort(event, property);
    };

    return (
        <TableHead>
            <TableRow>
                <TableCell padding="checkbox">
                    <Checkbox
                        color="primary"
                        indeterminate={numSelected > 0 && numSelected < rowCount}
                        checked={rowCount > 0 && numSelected === rowCount}
                        onChange={onSelectAllClick}
                        inputProps={{
                            'aria-label': 'select all desserts',
                        }}
                        />
                </TableCell>
                { encabezados.map( (headCell, index) => (
                    <TableCell
                        key={index}
                        align={headCell.numeric ? 'right' : 'left'}
                        padding={headCell.disablePadding ? 'none' : 'normal'}
                        sortDirection={orderBy === headCell.id ? order : false}
                    >
                        <TableSortLabel
                            style={{ fontWeight:'bold' }}
                            active={orderBy === headCell.id}
                            direction={orderBy === headCell.id ? order : 'asc'}
                            onClick={createSortHandler(headCell.id)}
                        >
                            {headCell.label}
                            {orderBy === headCell.id ? (
                                <Box component="span" sx={visuallyHidden}>
                                    {order === 'desc' ? 'sorted descending' : 'sorted ascending'}
                                </Box>
                            ) : null}
                        </TableSortLabel>
                    </TableCell>
                ))}
            </TableRow>
        </TableHead>
    );
}




